Module html

Module html 

Render the live JigMeta inventory as a single self-contained HTML page.

Functions

to_html
Render the pipeline rooted at the entry jig (the first jig returned by the iterator) as a complete HTML document. title is shown in the page header and <title> tag.